channelId property
The channelId parameter indicates that the API response should only
contain resources created by the channel.
Note: Search results are constrained to a maximum of 500 videos if your
request specifies a value for the channelId parameter and sets the type
parameter value to video, but it does not also set one of the
forContentOwner, forDeveloper, or forMine filters.
string
Implementation
final String? channelId;